/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.oauth2.provider.scope.liferay;

import org.osgi.framework.Bundle;

/**
 * Represents a context for the per-request scope check security procedure.
 *
 * @author Carlos Sierra Andrés
 */
public interface ScopeContext {

	/**
	 * Resets the state context's state.
	 */
	public void clear();

	/**
	 * Inserts the access token string into the context.
	 *
	 * @param accessToken the access token
	 */
	public void setAccessToken(String accessToken);

	/**
	 * Inserts the application name into the context.
	 *
	 * @param applicationName the application name
	 */
	public void setApplicationName(String applicationName);

	/**
	 * Inserts the OSGi bundle into the context.
	 *
	 * @param bundle the OSGi bundle
	 */
	public void setBundle(Bundle bundle);

	/**
	 * Inserts the portal instance's ID into the context.
	 *
	 * @param companyId the portal instance's ID
	 */
	public void setCompanyId(long companyId);

}